abacusai.cpu_gpu_memory_specs — AbacusAI documentation

# abacusai.cpu_gpu_memory_specs

## Classes

`CpuGpuMemorySpecs` | Includes the memory specs of the CPU/GPU

## Module Contents

class abacusai.cpu_gpu_memory_specs.CpuGpuMemorySpecs(client, default=None, data=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Includes the memory specs of the CPU/GPU

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - default (int) – the default memory size for the processing unit

    - data (list) – the list of memory sizes for the processing unit

  default = None
  data = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict